pub fn read_json_file<T: DeserializeOwned>(path: &Path) -> Result<T>Expand description
Reads and parses a JSON file.
Errors
Returns an error if the file cannot be read or parsed as valid JSON.
pub fn read_json_file<T: DeserializeOwned>(path: &Path) -> Result<T>Reads and parses a JSON file.
Returns an error if the file cannot be read or parsed as valid JSON.