pub fn read_toml_file<T: DeserializeOwned>(path: &Path) -> Result<T>Expand description
Reads and parses a TOML file.
Errors
Returns an error if the file cannot be read or parsed as valid TOML.
pub fn read_toml_file<T: DeserializeOwned>(path: &Path) -> Result<T>Reads and parses a TOML file.
Returns an error if the file cannot be read or parsed as valid TOML.