pub fn read_yaml_file<T: DeserializeOwned>(path: &Path) -> Result<T>Expand description
Reads and parses a YAML file.
Errors
Returns an error if the file cannot be read or parsed as valid YAML.
pub fn read_yaml_file<T: DeserializeOwned>(path: &Path) -> Result<T>Reads and parses a YAML file.
Returns an error if the file cannot be read or parsed as valid YAML.