pub trait Materializer {
// Required method
fn materialize(
&self,
workspace: &Workspace,
entries: &[LockfileEntry],
target_dir: &Path,
) -> Result<()>;
}Expand description
Trait for materializing dependencies.
Required Methods
Sourcefn materialize(
&self,
workspace: &Workspace,
entries: &[LockfileEntry],
target_dir: &Path,
) -> Result<()>
fn materialize( &self, workspace: &Workspace, entries: &[LockfileEntry], target_dir: &Path, ) -> Result<()>
Materialize dependencies into the target directory.
This should populate target_dir (e.g., with a node_modules folder
or target directory) containing the necessary dependencies.
Errors
Returns an error if dependencies cannot be linked or copied into the target directory (for example, due to missing files or filesystem permission issues).