Module javascript

Module javascript 

JavaScript package manager lockfile parsers.

Each parser translates a package manager specific lockfile into LockfileEntry instances using the shared LockfileParser trait. The implementations are gated behind fine-grained Cargo features so consumers can opt into only the parsers required for their toolchain.

Re-exports

pub use bun::BunLockfileParser;
pub use npm::NpmLockfileParser;
pub use pnpm::PnpmLockfileParser;
pub use yarn_classic::YarnClassicLockfileParser;
pub use yarn_modern::YarnModernLockfileParser;

Modules

bun
Bun lockfile parser module.
npm
npm lockfile parser module.
pnpm
pnpm lockfile parser module.
yarn_classic
Yarn Classic lockfile parser module.
yarn_modern
Yarn Modern lockfile parser module.